@@ -17,6 +17,7 @@ from ttkbootstrap.icons import Icon
 from ttkbootstrap.constants import *
 from tkinter import BaseWidget
 from ttkbootstrap.localization import MessageCatalog
+from ttkbootstrap.utility import center_on_parent
 
 
 class Dialog(BaseWidget):
@@ -50,22 +51,15 @@ class Dialog(BaseWidget):
 
     def _locate(self):
         toplevel = self._toplevel
-        if self._parent is None:
-            master = toplevel.master
-        else:
-            master = self._parent
-        x = master.winfo_rootx()
-        y = master.winfo_rooty()
-        toplevel.geometry(f"+{x}+{y}")
+        center_on_parent(toplevel, self._parent)
 
     def show(self, position=None, wait_for_result=True):
         """Show the popup dialog
         Parameters:
 
             position: Tuple[int, int]
-                The x and y coordinates used to position the dialog. By
-                default the dialog will anchor at the NW corner of the
-                parent window.
+                The x and y coordinates used to position the dialog. If no parent
+                then the dialog will anchor to the center of the parent window.
         """
         self._result = None
         self.build()
@@ -87,6 +81,7 @@ class Dialog(BaseWidget):
             self._initial_focus.focus_force()
 
         if wait_for_result:
+            self._toplevel.grab_set()
             self._toplevel.wait_window()
 
 
@@ -135,6 +130,7 @@ class Dialog(BaseWidget):
                 transient=self.master,
                 title=self._title,
                 resizable=(0, 0),
+                minsize=(250, 15),
                 windowtype="dialog",
                 iconify=True,
             )
@@ -157,6 +153,7 @@ class Dialog(BaseWidget):
     @property
     def result(self):
         """Returns the result of the dialog."""
+        self._toplevel.grab_release()
         return self._result
 
 
@@ -278,13 +275,13 @@ class MessageDialog(Dialog):
                 # assume this is image data
                 self._img = ttk.PhotoImage(data=self._icon)
                 icon_lbl = ttk.Label(container, image=self._img)
-                icon_lbl.pack(side=LEFT, padx=5)
+                icon_lbl.pack(side=LEFT, anchor=N, padx=(0, 5))
             except:
                 try:
                     # assume this is a file path
                     self._img = ttk.PhotoImage(file=self._icon)
                     icon_lbl = ttk.Label(container, image=self._img)
-                    icon_lbl.pack(side=LEFT, padx=5)
+                    icon_lbl.pack(side=LEFT, anchor=N, padx=(0, 5))
                 except:
                     # icon is neither data nor a valid file path
                     print("MessageDialog icon is invalid")
@@ -382,6 +379,7 @@ class QueryDialog(Dialog):
         datatype=str,
         padding=(20, 20),
         parent=None,
+        items=None,
     ):
         """
         Parameters:
@@ -423,10 +421,14 @@ class QueryDialog(Dialog):
 
             datatype (Union[int, str, float]):
                 The data type used to validate the entry value.
+
+            items (list[str]):
+                A list of possible string values to pick one from.
         """
         super().__init__(parent, title)
         self._prompt = prompt
         self._initialvalue = initialvalue
+        self._items = items
         self._minvalue = minvalue
         self._maxvalue = maxvalue
         self._width = width
@@ -443,8 +445,11 @@ class QueryDialog(Dialog):
                 prompt = "\n".join(textwrap.wrap(p, width=self._width))
                 prompt_label = ttk.Label(frame, text=prompt)
                 prompt_label.pack(pady=(0, 5), fill=X, anchor=N)
-
-        entry = ttk.Entry(master=frame)
+        if self._items is None or len(self._items) == 0:
+            entry = ttk.Entry(master=frame)
+        else:
+            entry = ttk.Combobox(master=frame, values=self._items)
+            entry.bind('<KeyRelease>', self.on_filter_list)
         entry.insert(END, self._initialvalue)
         entry.pack(pady=(0, 5), fill=X)
         entry.bind("<Return>", self.on_submit)
@@ -493,14 +498,25 @@ class QueryDialog(Dialog):
         self._toplevel.destroy()
         return
 
+    def on_filter_list(self, event):
+        """Filter the combobox list to items that contain the entered value"""
+        value = event.widget.get().lower()
+        if not value:
+            event.widget["values"] = self._items
+        else:
+            data = [k for k in self._items if value in k.lower()]
+            event.widget["values"] = data
+
     def validate(self):
         """Validate the data
 
         This method is called automatically to validate the data before
         the dialog is destroyed. Can be subclassed and overridden.
         """
-        # no default checks required for string data types
-        if self._datatype not in [float, int, complex]:
+        # no default checks required for string data types,
+        # unless there is a list of items to pick from
+        if self._datatype not in [float, int, complex] and\
+            (self._items is None or len(self._items) == 0):
             return True
 
         # convert result to appropriate data type
@@ -537,6 +553,17 @@ class QueryDialog(Dialog):
                 )
                 return False
 
+        # item in list
+        if self._items is not None and len(self._items) > 0:
+            if self._result not in self._items:
+                msg = MessageCatalog.translate("Select an item from the list")
+                Messagebox.ok(
+                    message=msg,
+                    title=MessageCatalog.translate("Out of range"),
+                    parent=self._toplevel
+                )
+                return False
+
         # valid result
         return True
 
@@ -593,7 +620,7 @@ class DatePickerDialog:
             parent (Widget):
                 The parent widget; the popup will appear to the
                 bottom-right of the parent widget. If no parent is
-                provided, the widget is centered on the screen.
+                provided, the widget is centered on the parent window.
 
             title (str):
                 The text that appears on the titlebar.
@@ -663,8 +690,9 @@ class DatePickerDialog:
         self._draw_calendar()
 
         # make toplevel visible
-        self._set_window_position()
+        self.root.update_idletasks()
         self.root.deiconify()
+        self._set_window_position()
 
     def _update_widget_bootstyle(self):
         self.frm_title.configure(bootstyle=self.bootstyle)
@@ -710,6 +738,7 @@ class DatePickerDialog:
                         variable=self.datevar,
                         value=day,
                         text=day,
+                        takefocus=True,
                         bootstyle=day_style,
                         padding=5,
                         command=selected,
@@ -865,8 +894,8 @@ class DatePickerDialog:
         self.date = self.startdate
 
     def _set_window_position(self):
-        """Move the window the to bottom-right of the parent widget, or
-        the top-left corner of the master window if no parent is
+        """Move the window to the bottom-right of the parent widget, or
+        the center of the master window if no parent is
         provided.
         """
         if self.parent:
@@ -874,9 +903,7 @@ class DatePickerDialog:
             ypos = self.parent.winfo_rooty() + self.parent.winfo_height()
             self.root.geometry(f"+{xpos}+{ypos}")
         else:
-            xpos = self.root.master.winfo_rootx()
-            ypos = self.root.master.winfo_rooty()
-            self.root.geometry(f"+{xpos}+{ypos}")
+            center_on_parent(self.root, self.parent)
 
     @staticmethod
     def _nextmonth(year, month):
@@ -1001,7 +1028,7 @@ class FontDialog(Dialog):
         listbox_vbar.pack(side=RIGHT, fill=Y)
         listbox.configure(yscrollcommand=listbox_vbar.set)
 
-        for f in self._families:
+        for f in sorted(self._families):
             listbox.insert("", iid=f, index=END, tags=[f], values=[f])
             listbox.tag_configure(f, font=(f, self._size.get()))
 
@@ -1749,6 +1776,54 @@ class Querybox:
         dialog.show(position)
         return dialog._result
 
+    @staticmethod
+    def get_item(
+        prompt="", title=" ", initialvalue=None, items=None, parent=None, **kwargs
+    ):
+        """Request an item from a list of items from the user.
+
+        ![](../../assets/dialogs/querybox-get-item.png)
+
+        Parameters:
+
+            prompt (str):
+                A message to display in the message box above the combobox
+                widget.
+
+            title (str):
+                The string displayed as the title of the message box. This
+                option is ignored on Mac OS X, where platform guidelines
+                forbid the use of a title on this kind of dialog.
+
+            initialvalue (Any):
+                The initial value in the combobox widget.
+
+            items (list[str]):
+                A list of string values to pick one from.
+
+            parent (Widget):
+                Makes the window the logical parent of the message box. The
+                messagebox is displayed on top of its parent window.
+
+            **kwargs (Dict):
+                Other optional keyword arguments.
+
+        Returns:
+
+            str:
+                The string value selected in the combobox widget.
+        """
+        initialvalue = initialvalue or ""
+        if "position" in kwargs:
+            position = kwargs.pop("position")
+        else:
+            position = None
+        dialog = QueryDialog(
+            prompt, title, initialvalue, items=items, parent=parent, **kwargs
+        )
+        dialog.show(position)
+        return dialog._result
+
     @staticmethod
     def get_integer(
         prompt="",
