@@ -1,11 +1,12 @@
 import tkinter as tk
-import ttkbootstrap as ttk
-from ttkbootstrap.constants import *
-from math import ceil
 from datetime import datetime
+from math import ceil
 from tkinter import font
-from ttkbootstrap import utility
 from typing import Any, Dict, List, Union
+
+import ttkbootstrap as ttk
+from ttkbootstrap import utility
+from ttkbootstrap.constants import *
 from ttkbootstrap.localization import MessageCatalog
 
 UPARROW = "⬆"
@@ -440,6 +441,7 @@ class Tableview(ttk.Frame):
             pagesize=10,
             height=10,
             delimiter=",",
+            disable_right_click=False,
     ):
         """
         Parameters:
@@ -522,6 +524,9 @@ class Tableview(ttk.Frame):
             delimiter (str):
                 The character to use as a delimiter when exporting data
                 to CSV.
+
+            disable_right_click (bool):
+                When set to `True`, the built-in right click menus are disabled on the widget.
         """
         super().__init__(master)
         self._tablecols = []
@@ -546,6 +551,7 @@ class Tableview(ttk.Frame):
         self._delimiter = delimiter
         self._iidmap = {}  # maps iid to row object
         self._cidmap = {}  # maps cid to col object
+        self.disable_right_click = disable_right_click
 
         self.view: ttk.Treeview = None
         self._build_tableview_widget(coldata, rowdata, bootstyle)
@@ -701,9 +707,7 @@ class Tableview(ttk.Frame):
     def insert_row(self, index=END, values=[]) -> TableRow:
         """Insert a row into the tableview at index.
 
-        You must call `Tableview.load_table_data()` to update the
-        current view. If the data is filtered, you will need to call
-        `Tableview.load_table_data(clear_filters=True)`.
+        Inserting a row will reload the table data and clear the applied filters.
 
         Parameters:
 
@@ -729,7 +733,8 @@ class Tableview(ttk.Frame):
 
         # validate the index
         if len(values) == 0:
-            return
+            print('[TableView] Cannot insert. No values found.')
+            return None
         if index == END:
             index = -1
         elif index > rowcount - 1:
@@ -741,6 +746,8 @@ class Tableview(ttk.Frame):
         else:
             self._tablerows.insert(index, record)
 
+        self.load_table_data(self.is_filtered)
+
         return record
 
     def insert_rows(self, index, rowdata):
@@ -749,6 +756,10 @@ class Tableview(ttk.Frame):
         You can also use the string 'end' to append records at the end
         of the table.
 
+        Rows are inserted in reverse order.
+
+        Inserting rows will rebuild the table view and clear the filters.
+
         Parameters:
 
             index (Union[int, str]):
@@ -1026,7 +1037,10 @@ class Tableview(ttk.Frame):
     def unload_table_data(self):
         """Unload all data from the table"""
         for row in self.tablerows_visible:
-            row.hide()
+            tmp_row_id = row.iid
+            for tmp in self._tablerows:
+                if tmp_row_id == tmp.iid:
+                    row.hide()
         self.tablerows_visible.clear()
 
     def load_table_data(self, clear_filters=False):
@@ -2081,7 +2095,7 @@ class Tableview(ttk.Frame):
         """Build the data table"""
         if self._searchable:
             self._build_search_frame()
-            
+
         table_frame = ttk.Frame(self)
         table_frame.pack(fill=BOTH, expand=YES, side=TOP)
 
@@ -2094,14 +2108,14 @@ class Tableview(ttk.Frame):
             bootstyle=f"{bootstyle}-table",
         )
         self.view.pack(fill=BOTH, expand=YES, side=LEFT)
-        
+
         if self._yscrollbar:
             self.ybar = ttk.Scrollbar(
                 master=table_frame, command=self.view.yview, orient=VERTICAL
             )
             self.ybar.pack(fill=Y, side=RIGHT)
             self.view.configure(yscrollcommand=self.ybar.set)
-        
+
         self.hbar = ttk.Scrollbar(
             master=self, command=self.view.xview, orient=HORIZONTAL
         )
@@ -2113,8 +2127,10 @@ class Tableview(ttk.Frame):
 
         self.build_table_data(coldata, rowdata)
 
-        self._rightclickmenu_cell = TableCellRightClickMenu(self)
-        self._rightclickmenu_head = TableHeaderRightClickMenu(self)
+        if not self.disable_right_click:
+            self._rightclickmenu_cell = TableCellRightClickMenu(self)
+            self._rightclickmenu_head = TableHeaderRightClickMenu(self)
+
         self._set_widget_binding()
 
     def _build_search_frame(self):
@@ -2235,11 +2251,13 @@ class Tableview(ttk.Frame):
         """Setup the widget binding"""
         self.view.bind("<Double-Button-1>", self._header_double_leftclick)
         self.view.bind("<Button-1>", self._header_leftclick)
-        if self.tk.call("tk", "windowingsystem") == "aqua":
-            sequence = "<Button-2>"
-        else:
-            sequence = "<Button-3>"
-        self.view.bind(sequence, self._table_rightclick)
+
+        if not self.disable_right_click:
+            if self.tk.call("tk", "windowingsystem") == "aqua":
+                sequence = "<Button-2>"
+            else:
+                sequence = "<Button-3>"
+            self.view.bind(sequence, self._table_rightclick)
 
         # add trace to track pagesize changes
         self._pagesize.trace_add("write", self._trace_pagesize)
