@@ -1,4 +1,4 @@
-from typing import Literal
+from typing import Literal, Optional
 
 import ttkbootstrap as ttk
 from ttkbootstrap.constants import *
@@ -46,7 +46,7 @@ class ToolTip:
             wraplength=None,
             delay=250,  # milliseconds
             image=None,
-            position: str | None = None,
+            position: Optional[str] = None,
             **kwargs,
     ):
         """
@@ -105,18 +105,6 @@ class ToolTip:
             kwargs["alpha"] = 0.95
         self.toplevel_kwargs = kwargs
 
-        # create default tooltip style
-        ttk.Style().configure(
-            style="tooltip.TLabel",
-            background="#fffddd",
-            foreground="#333",
-            bordercolor="#888",
-            borderwidth=1,
-            darkcolor="#fffddd",
-            lightcolor="#fffddd",
-            relief=RAISED,
-        )
-
         # event binding
         self.widget.bind("<Enter>", self.enter)
         self.widget.bind("<Leave>", self.leave)
